@@ -6,7 +6,7 @@
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* FIXME: we should not use the default assuan buffering but setup
@@ -58,6 +56,10 @@ struct server_local_s
   char *keydesc;  /* Allocated description for the next key
                      operation. */
   int pause_io_logging; /* Used to suppress I/O logging during a command */
+#ifdef HAVE_W32_SYSTEM
+  int stopme;    /* If set to true the agent will be terminated after
+                    the end of this session.  */
+#endif
 };
 
 
@@ -1306,6 +1308,78 @@ cmd_updatestartuptty (assuan_context_t ctx, char *line)
 }
 
 
+
+#ifdef HAVE_W32_SYSTEM
+/* KILLAGENT
+
+   Under Windows we start the agent on the fly.  Thus it also make
+   sense to allow a client to stop the agent. */
+static int
+cmd_killagent (assuan_context_t ctx, char *line)
+{
+  ctrl_t ctrl = assuan_get_pointer (ctx);
+  ctrl->server_local->stopme = 1;
+  return 0;
+}
+
+/* RELOADAGENT
+
+   As signals are inconvenient under Windows, we provide this command
+   to allow reloading of the configuration.  */
+static int
+cmd_reloadagent (assuan_context_t ctx, char *line)
+{
+  agent_sighup_action ();
+  return 0;
+}
+#endif /*HAVE_W32_SYSTEM*/
+
+
+
+/* GETINFO <what>
+
+   Multipurpose function to return a variety of information.
+   Supported values for WHAT are:
+
+     version     - Return the version of the program.
+     socket_name - Return the name of the socket.
+     ssh_socket_name - Return the name of the ssh socket.
+
+ */
+static int
+cmd_getinfo (assuan_context_t ctx, char *line)
+{
+  int rc = 0;
+
+  if (!strcmp (line, "version"))
+    {
+      const char *s = VERSION;
+      rc = assuan_send_data (ctx, s, strlen (s));
+    }
+  else if (!strcmp (line, "socket_name"))
+    {
+      const char *s = get_agent_socket_name ();
+
+      if (s)
+        rc = assuan_send_data (ctx, s, strlen (s));
+      else
+        rc = gpg_error (GPG_ERR_NO_DATA);
+    }
+  else if (!strcmp (line, "ssh_socket_name"))
+    {
+      const char *s = get_agent_ssh_socket_name ();
+
+      if (s)
+        rc = assuan_send_data (ctx, s, strlen (s));
+      else
+        rc = gpg_error (GPG_ERR_NO_DATA);
+    }
+  else
+    rc = set_error (GPG_ERR_ASS_PARAMETER, "unknown value for WHAT");
+  return rc;
+}
+
+
 
 static int
 option_handler (assuan_context_t ctx, const char *key, const char *value)
@@ -1439,6 +1513,11 @@ register_commands (assuan_context_t ctx)
     { "GETVAL",         cmd_getval },
     { "PUTVAL",         cmd_putval },
     { "UPDATESTARTUPTTY",  cmd_updatestartuptty },
+#ifdef HAVE_W32_SYSTEM
+    { "KILLAGENT",      cmd_killagent },
+    { "RELOADAGENT",    cmd_reloadagent },
+#endif
+    { "GETINFO",        cmd_getinfo },
     { NULL }
   };
   int i, rc;
@@ -1542,6 +1621,10 @@ start_command_handler (ctrl_t ctrl, int listen_fd, int fd)
 
   /* Cleanup.  */
   assuan_deinit_server (ctx);
+#ifdef HAVE_W32_SYSTEM
+  if (ctrl->server_local->stopme)
+    agent_exit (0);
+#endif
   xfree (ctrl->server_local);
   ctrl->server_local = NULL;
 }
