@@ -14,11 +14,9 @@
 #ifndef GNUPG_COMMON_I18N_H
 #define GNUPG_COMMON_I18N_H
 
+
 #ifdef USE_SIMPLE_GETTEXT
-  int set_gettext_file( const char *filename );
-  const char *gettext( const char *msgid );
-  const char *ngettext(const char *msgid1, const char *msgid2,
-                       unsigned long int n);
+# include "../jnlib/w32help.h"
 # define _(a) gettext (a)
 # define N_(a) (a)
 #else
@@ -40,4 +38,7 @@
 # endif
 #endif /*!USE_SIMPLE_GETTEXT*/
 
+void i18n_init (void);
+
+
 #endif /*GNUPG_COMMON_I18N_H*/
