@@ -5,7 +5,7 @@
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* This file implements a few utility functions useful when working
@@ -34,7 +32,7 @@
 #endif
 
 #include "util.h"
-
+#include "sexp-parse.h"
 
 /* Return the so called "keygrip" which is the SHA-1 hash of the
    public key parameters expressed in a way depended on the algorithm.
@@ -115,7 +113,8 @@ make_simple_sexp_from_hexstr (const char *line, size_t *nscanned)
   const char *s;
   unsigned char *buf;
   unsigned char *p;
-  char numbuf[50];
+  char numbuf[50], *numbufp;
+  size_t numbuflen;
 
   for (n=0, s=line; hexdigitp (s); s++, n++)
     ;
@@ -124,11 +123,12 @@ make_simple_sexp_from_hexstr (const char *line, size_t *nscanned)
   if (!n)
     return NULL;
   len = ((n+1) & ~0x01)/2; 
-  sprintf (numbuf, "(%u:", (unsigned int)len);
-  buf = xtrymalloc (strlen (numbuf) + len + 1 + 1);
+  numbufp = smklen (numbuf, sizeof numbuf, len, &numbuflen);
+  buf = xtrymalloc (1 + numbuflen + len + 1 + 1);
   if (!buf)
     return NULL;
-  p = (unsigned char *)stpcpy ((char *)buf, numbuf);
+  buf[0] = '(';
+  p = (unsigned char *)stpcpy ((char *)buf+1, numbufp);
   s = line;
   if ((n&1))
     {
