@@ -112,7 +112,7 @@ const char *isotimestamp (u32 stamp); /* GMT */
 const char *asctimestamp (u32 stamp); /* localized */
 
 
-/* Copy one iso ddate to another, this is inline so that we can do a
+/* Copy one ISO date to another, this is inline so that we can do a
    sanity check. */
 static inline void
 gnupg_copy_time (gnupg_isotime_t d, const gnupg_isotime_t s)
@@ -178,6 +178,7 @@ const char *gnupg_bindir (void);
 const char *gnupg_libexecdir (void);
 const char *gnupg_libdir (void);
 const char *gnupg_datadir (void);
+const char *dirmngr_socket_name (void);
 
 #define GNUPG_MODULE_NAME_AGENT        1
 #define GNUPG_MODULE_NAME_PINENTRY     2
