@@ -5,7 +5,7 @@
  *
  * JNLIB is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
+ * published by the Free Software Foundation; either version 3 of
  * the License, or (at your option) any later version.
  *
  * JNLIB is distributed in the hope that it will be useful, but
@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /****************
@@ -34,11 +32,14 @@
 #define JNLIB_NEED_UTF8CONV 1
 
 
+
+#if !defined(JNLIB_NEED_UTF8CONV) && defined(HAVE_W32_SYSTEM)
+#define JNLIB_NEED_UTF8CONV 1
+#endif
+
 /* Gettext stuff */
 #ifdef USE_SIMPLE_GETTEXT
-  int set_gettext_file( const char *filename );
-  const char *gettext( const char *msgid );
-
+# include "w32help.h"
 # define _(a) gettext (a)
 # define N_(a) (a)
 
@@ -61,7 +62,9 @@
 #endif
 #endif /* !USE_SIMPLE_GETTEXT */
 
-/* Malloc functions to be jused by jnlib.  */
+/* Malloc functions to be used by jnlib.  */
+#define jnlib_malloc(a)     gcry_malloc( (a) )
+#define jnlib_calloc(a,b)   gcry_calloc( (a), (b) )
 #define jnlib_xmalloc(a)    gcry_xmalloc( (a) )
 #define jnlib_xcalloc(a,b)  gcry_xcalloc( (a), (b) )
 #define jnlib_xrealloc(a,n) gcry_xrealloc( (a), (n) )
