@@ -34,8 +34,6 @@
 #include "i18n.h"
 #include "keydb.h"
 
-/* The name of the socket for a system daemon.  */
-#define DEFAULT_SOCKET_NAME "/var/run/dirmngr/socket"
 
 struct membuf {
   size_t len;
@@ -155,14 +153,23 @@ start_dirmngr (void)
   /* Note: if you change this to multiple connections, you also need
      to take care of the implicit option sending caching. */
 
+#ifdef HAVE_W32_SYSTEM
+  infostr = NULL;
+  opt.prefer_system_dirmngr = 1;
+#else
   infostr = force_pipe_server? NULL : getenv ("DIRMNGR_INFO");
-  if (opt.prefer_system_dirmngr && !force_pipe_server
-      &&(!infostr || !*infostr))
+#endif /*HAVE_W32_SYSTEM*/
+  if (infostr && !*infostr)
+    infostr = NULL;
+  else if (infostr)
+    infostr = xstrdup (infostr);
+
+  if (opt.prefer_system_dirmngr && !force_pipe_server && !infostr)
     {
-      infostr = DEFAULT_SOCKET_NAME;
+      infostr = xstrdup (dirmngr_socket_name ());
       try_default = 1;
     }
-  if (!infostr || !*infostr)
+  if (!infostr)
     {
       const char *pgmname;
       const char *argv[3];
@@ -206,8 +213,7 @@ start_dirmngr (void)
       int prot;
       int pid;
 
-      infostr = xstrdup (infostr);
-      if (!try_default && *infostr)
+      if (!try_default)
         {
           if ( !(p = strchr (infostr, PATHSEP_C)) || p == infostr)
             {
@@ -234,13 +240,20 @@ start_dirmngr (void)
         pid = -1;
 
       rc = assuan_socket_connect (&ctx, infostr, pid);
+#ifdef HAVE_W32_SYSTEM
+      if (rc)
+        log_debug ("connecting dirmngr at `%s' failed\n", infostr);
+#endif
+
       xfree (infostr);
+#ifndef HAVE_W32_SYSTEM
       if (gpg_err_code (rc) == GPG_ERR_ASS_CONNECT_FAILED)
         {
           log_error (_("can't connect to the dirmngr - trying fall back\n"));
           force_pipe_server = 1;
           return start_dirmngr ();
         }
+#endif /*!HAVE_W32_SYSTEM*/
     }
 
   if (rc)
@@ -394,8 +407,10 @@ isvalid_status_cb (void *opaque, const char *line)
   GPG_ERR_NO_CRL_KNOWN
   GPG_ERR_CRL_TOO_OLD
 
-  With USE_OCSP set to true, the dirmngr is asked to do an OCSP
-  request first.
+  Values for USE_OCSP:
+     0 = Do CRL check.
+     1 = Do an OCSP check.
+     2 = Do an OCSP check using only the default responder.
  */
 int
 gpgsm_dirmngr_isvalid (ctrl_t ctrl,
@@ -445,7 +460,8 @@ gpgsm_dirmngr_isvalid (ctrl_t ctrl,
 
   /* FIXME: If --disable-crl-checks has been set, we should pass an
      option to dirmngr, so that no fallback CRL check is done after an
-     ocsp check. */
+     ocsp check.  It is not a problem right now as dirmngr does not
+     fallback to CRL checking.  */
 
   /* It is sufficient to send the options only once because we have
      one connection per process only. */
@@ -456,7 +472,9 @@ gpgsm_dirmngr_isvalid (ctrl_t ctrl,
                          NULL, NULL, NULL, NULL, NULL, NULL);
       did_options = 1;
     }
-  snprintf (line, DIM(line)-1, "ISVALID %s", certid);
+  snprintf (line, DIM(line)-1, "ISVALID%s %s", 
+            use_ocsp == 2? " --only-ocsp --force-default-responder":"",
+            certid);
   line[DIM(line)-1] = 0;
   xfree (certid);
 
@@ -504,9 +522,10 @@ gpgsm_dirmngr_isvalid (ctrl_t ctrl,
                 rc = gpg_error (GPG_ERR_INV_CRL);
               else
                 {
-                  /* Note, the flag = 1: This avoids checking this
-                     certificate over and over again. */
-                  rc = gpgsm_validate_chain (ctrl, rspcert, NULL, 0, NULL, 1);
+                  /* Note the no_dirmngr flag: This avoids checking
+                     this certificate over and over again. */
+                  rc = gpgsm_validate_chain (ctrl, rspcert, "", NULL, 0, NULL, 
+                                             VALIDATE_FLAG_NO_DIRMNGR, NULL);
                   if (rc)
                     {
                       log_error ("invalid certificate used for CRL/OCSP: %s\n",
