@@ -5,7 +5,7 @@
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -416,7 +414,7 @@ gpgsm_p12_export (ctrl_t ctrl, const char *name, FILE *fp)
       putc ('\n', fp);
     }
 
-  if (opt.p12_charset)
+  if (opt.p12_charset && ctrl->create_pem)
     {
       fprintf (fp, "The passphrase is %s encoded.\n\n",
                opt.p12_charset);
@@ -604,7 +602,7 @@ export_p12 (ctrl_t ctrl, const unsigned char *certimg, size_t certimglen,
   int bad_pass = 0;
 
   if (!opt.protect_tool_program || !*opt.protect_tool_program)
-    pgmname = GNUPG_DEFAULT_PROTECT_TOOL;
+    pgmname = gnupg_module_name (GNUPG_MODULE_NAME_PROTECT_TOOL);
   else
     pgmname = opt.protect_tool_program;
 
